Type: Package
Package: hatchR
Title: Predict Fish Hatch and Emergence Timing
Version: 1.0.1
Authors@R: c(
    person("Bryan M.", "Maitland", email = "bryan.maitland@usda.gov", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-4491-5064")),
    person("Morgan M.", "Sparks", email = "morgan.sparks@usda.gov", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0003-0787-2218")),
    person("Eli", "Felts", email = "eli_felts@fws.gov", role = "ctb",
           comment = c(ORCID = "0000-0002-5888-9266")),
    person("Allison", "Swartz", email = "allison.swartz@oregonstate.edu", role = "ctb"),
    person("Paul", "Frater", email = "paul.frater@wisconsin.gov", role = "ctb")
  )
Maintainer: Bryan M. Maitland <bryan.maitland@usda.gov>
Description: Predict hatch and emergence timing for a wide range of wild
    fishes using the effective value framework (Sparks et al., (2019)
    <DOI:10.1139/cjfas-2017-0468>). 'hatchR' offers users access to
    established phenological models and the flexibility to incorporate
    custom parameterizations using external datasets.
License: GPL-3
URL: https://bmait101.github.io/hatchR/,
        https://github.com/bmait101/hatchR
BugReports: https://github.com/bmait101/hatchR/issues
Depends: R (>= 4.1.0)
Imports: dplyr (>= 1.1.4), ggplot2 (>= 3.5.2), ggtext (>= 0.1.2),
        lifecycle (>= 1.0.4), lubridate (>= 1.9.4), rlang (>= 1.1.4),
        stats, tibble (>= 3.2.1), utils
Suggests: cli (>= 3.6.1), ggridges (>= 0.5.6), knitr (>= 1.49),
        nycflights13 (>= 1.0.2), patchwork (>= 1.3.0), purrr (>=
        1.0.2), readr (>= 2.1.5), rmarkdown (>= 2.29), stringr (>=
        1.5.1), testthat (>= 3.0.0), tidyr (>= 1.3.1)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-07-29 14:55:16 UTC; BryanMaitland
Author: Bryan M. Maitland [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4491-5064>),
  Morgan M. Sparks [aut, cph] (ORCID:
    <https://orcid.org/0000-0003-0787-2218>),
  Eli Felts [ctb] (ORCID: <https://orcid.org/0000-0002-5888-9266>),
  Allison Swartz [ctb],
  Paul Frater [ctb]
Repository: CRAN
Date/Publication: 2025-07-29 15:30:07 UTC
Built: R 4.6.0; ; 2026-04-26 13:25:24 UTC; unix
