# Generated by roxygen2: do not edit by hand

export(check_continuous)
export(fit_model)
export(model_select)
export(plot_check_temp)
export(plot_phenology)
export(predict_phenology)
export(predict_spawn)
export(summarize_temp)
importFrom(lifecycle,deprecated)
importFrom(rlang,.data)
importFrom(utils,globalVariables)
